@@ -1,7 +1,11 @@
+import os
 import glob
 import pickle
 
-def lookup_stack_files():
+def lookup_stack_files(dir=None):
+	if dir:
+		os.chdir(dir)
+
 	stack_files = glob.glob('*.stk')
 	return stack_files
 
@@ -21,3 +25,7 @@ def read_stack_files(stack_files):
 		
 	return contents
 
+def save_stack_files(files, stack_index, stack_name):
+	pass
+
+
